@@ -208,13 +208,14 @@ SearchEngine::~SearchEngine()
 
 bool SearchEngine::initSearchHandlers()
 {
-  const QStringList resourceDirs = QStandardPaths::locateAll(QStandardPaths::DataLocation, QStringLiteral("searchhandlers/"), QStandardPaths::LocateDirectory );
+  const QStringList resourceDirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("searchhandlers/"), QStandardPaths::LocateDirectory );
   QStringList resources;
-  foreach(const QString& dir, resourceDirs) {
+  for(const QString& dir : resourceDirs) {
       QDir d(dir);
-    foreach ( const QString& entry, d.entryList( QStringList( QStringLiteral("*.desktop") ), QDir::Files ) ) {
-      resources += dir + entry;
-    }
+      const auto entryList = d.entryList( QStringList( QStringLiteral("*.desktop") ), QDir::Files );
+      for ( const QString& entry : entryList  ) {
+          resources += dir + entry;
+      }
   }
 
   QStringList::ConstIterator it;
@@ -240,7 +241,7 @@ bool SearchEngine::initSearchHandlers()
   }
 
   if ( mHandlers.isEmpty() ) {
-    QString txt = i18n("No valid search handler found.");
+    const QString txt = i18n("No valid search handler found.");
     qCWarning(KHC_LOG) << txt;
 //    KMessageBox::sorry( mView->widget(), txt );
     return false;
@@ -270,7 +271,7 @@ bool SearchEngine::search( const QString & words, const QString & method, int ma
     return false;
   }
 
-  QString txt = i18n("Search Results for '%1':", words.toHtmlEscaped() );
+  const QString txt = i18n("Search Results for '%1':", words.toHtmlEscaped() );
 
   mStderr = QStringLiteral("<b>") + txt + QStringLiteral("</b>\n");
 
@@ -293,7 +294,7 @@ QString SearchEngine::substituteSearchQuery( const QString &query,
   result.replace( QLatin1String("%i"), identifier );
   result.replace( QLatin1String("%w"), words.join( QLatin1Char('+') ) );
   result.replace( QLatin1String("%m"), QString::number( maxResults ) );
-  QString o = QLatin1String(operation == Or ? "or" : "and");
+  const QString o = QLatin1String(operation == Or ? "or" : "and");
   result.replace( QLatin1String("%o"), o );
   result.replace( QLatin1String("%d"), Prefs::indexDirectory() );
   result.replace( QLatin1String("%l"), lang );
@@ -318,7 +319,7 @@ void SearchEngine::finishSearch()
   mRootTraverser = nullptr;
   mSearchRunning = false;
 
-  emit searchFinished();
+  Q_EMIT searchFinished();
 }
 
 QString SearchEngine::errorLog() const
